@@ -16,22 +16,22 @@
 # define PTRACE_POKEUSER PTRACE_POKEUSR
 #endif
 
-void *
-get_instruction_pointer(struct process * proc) {
-	return (void *)ptrace(PTRACE_PEEKUSER, proc->pid, 4*EIP, 0);
+void *get_instruction_pointer(struct process *proc)
+{
+	return (void *)ptrace(PTRACE_PEEKUSER, proc->pid, 4 * EIP, 0);
 }
 
-void
-set_instruction_pointer(struct process * proc, void * addr) {
-	ptrace(PTRACE_POKEUSER, proc->pid, 4*EIP, (long)addr);
+void set_instruction_pointer(struct process *proc, void *addr)
+{
+	ptrace(PTRACE_POKEUSER, proc->pid, 4 * EIP, (long)addr);
 }
 
-void *
-get_stack_pointer(struct process * proc) {
-	return (void *)ptrace(PTRACE_PEEKUSER, proc->pid, 4*UESP, 0);
+void *get_stack_pointer(struct process *proc)
+{
+	return (void *)ptrace(PTRACE_PEEKUSER, proc->pid, 4 * UESP, 0);
 }
 
-void *
-get_return_addr(struct process * proc, void * stack_pointer) {
+void *get_return_addr(struct process *proc, void *stack_pointer)
+{
 	return (void *)ptrace(PTRACE_PEEKTEXT, proc->pid, stack_pointer, 0);
 }
